@@ -407,9 +407,12 @@ class Machine(MachineBase):
         """
         self._apt("install -yq nginx libnginx-mod-rtmp")
         self.nginx_conf = "/etc/nginx/nginx.conf"
-        self.web_data = "/var/www"
+        # XXX self.web_data = "/var/www"
         self.open_ports(80, 443)
-        self.run(f"mkdir {self.web_data}")
+        streaming_dir = "/home/gaea/media/streaming"
+        self.run(f"mkdir {streaming_dir} -P")
+        self.run(f"mkdir {streaming_dir}/hls")
+        self.run(f"mkdir {streaming_dir}/rec")
         self.run(
             f"cat > {self.nginx_conf}",
             stdin=str(templates.nginx_conf(self.address, self.onion)),
